# Kedro Databricks plugin

[![Python Version](https://img.shields.io/pypi/pyversions/kedro-databricks)](https://github.com/getindata/kedro-databricks)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![SemVer](https://img.shields.io/badge/semver-2.0.0-green)](https://semver.org/)
[![PyPI version](https://badge.fury.io/py/kedro-databricks.svg)](https://pypi.org/project/kedro-databricks/)
[![Downloads](https://pepy.tech/badge/kedro-databricks)](https://pepy.tech/project/kedro-databricks)

[![Maintainability Rating](https://sonarcloud.io/api/project_badges/measure?project=getindata_kedro-databricks&metric=sqale_rating)](https://sonarcloud.io/summary/new_code?id=getindata_kedro-databricks)
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=getindata_kedro-databricks&metric=coverage)](https://sonarcloud.io/summary/new_code?id=getindata_kedro-databricks)
[![Documentation Status](https://readthedocs.org/projects/kedro-databricks/badge/?version=latest)](https://kedro-databricks.readthedocs.io/en/latest/?badge=latest)

<p align="center">
  <a href="https://getindata.com/solutions/ml-platform-machine-learning-reliable-explainable-feature-engineering"><img height="150" src="https://getindata.com/img/logo.svg"></a>
  <h3 align="center">We help companies turn their data into assets</h3>
</p>

# Coming soon!
Stay tuned or connect with us directly.

